@@ -32,7 +32,7 @@ extern long subllx(ulong x, ulong y);
 
 #if defined(__GNUC__) && !defined(DISABLE_INLINE)
 #undef LOCAL_OVERFLOW
-#define LOCAL_OVERFLOW register ulong overflow
+#define LOCAL_OVERFLOW ulong overflow
 
 #define addll(a, b)                                             \
 __extension__ ({                                                \
@@ -146,7 +146,7 @@ extern long addmul(ulong x, ulong y);
 
 #if defined(__GNUC__) && !defined(DISABLE_INLINE)
 #undef LOCAL_HIREMAINDER
-#define LOCAL_HIREMAINDER register ulong hiremainder
+#define LOCAL_HIREMAINDER ulong hiremainder
 
 #define mulll(x, y) \
 __extension__ ({ \
@@ -263,8 +263,8 @@ ASM addll mulll
 NOASM bfffo divll
 */
 #ifdef ASMINLINE
-#define LOCAL_HIREMAINDER  register ulong hiremainder
-#define LOCAL_OVERFLOW     register ulong overflow
+#define LOCAL_HIREMAINDER  ulong hiremainder
+#define LOCAL_OVERFLOW     ulong overflow
 
 #define addll(a, b) \
 __extension__ ({ ulong __value, __arg1 = (a), __arg2 = (b); \
@@ -432,7 +432,7 @@ extern ulong hiremainder;
 
 #if defined(__GNUC__) && !defined(DISABLE_INLINE)
 #undef LOCAL_HIREMAINDER
-#define LOCAL_HIREMAINDER register ulong hiremainder
+#define LOCAL_HIREMAINDER ulong hiremainder
 
 #define divll(n0, d)                                                    \
 __extension__ ({                                                        \
@@ -571,7 +571,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. */
 #undef  LOCAL_HIREMAINDER
 extern ulong hiremainder;
 #if defined(INLINE) && defined(__GNUC__) && !defined(DISABLE_INLINE)
-#define LOCAL_HIREMAINDER register ulong hiremainder
+#define LOCAL_HIREMAINDER ulong hiremainder
 #else
 #define LOCAL_HIREMAINDER
 #endif
@@ -973,6 +973,8 @@ affrr_fixlg(GEN y, GEN z) { fixlg(z, lg(y)); affrr(y, z); }
 /*                       ALLOCATE ON STACK                         */
 /*                                                                 */
 /*******************************************************************/
+INLINE ulong
+get_avma(void) { return avma; }
 INLINE void
 set_avma(ulong av) { avma = av; }
 
@@ -1111,7 +1113,7 @@ cgetr(long x)
 INLINE GEN
 leafcopy(GEN x)
 {
-  register long lx = lg(x);
+  long lx = lg(x);
   GEN y = new_chunk(lx); /* can't use cgetg_copy, in case x,y overlap */
   while (--lx > 0) y[lx] = x[lx];
   y[0] = x[0] & (TYPBITS|LGBITS); return y;
@@ -1627,8 +1629,9 @@ udivuu_rem(ulong x, ulong y, ulong *r)
 INLINE ulong
 ceildivuu(ulong a, ulong b)
 {
-  ulong c = a/b;
-  return (a%b)? c+1: c;
+  ulong c;
+  if (!a) return 0;
+  c = a / b; return (a % b)? c+1: c;
 }
 
 INLINE ulong
@@ -1888,7 +1891,7 @@ remlll_pre(ulong u2, ulong u1, ulong u0, ulong n, ulong ninv)
 INLINE ulong
 Fl_sqr_pre(ulong a, ulong p, ulong pi)
 {
-  register ulong x;
+  ulong x;
   LOCAL_HIREMAINDER;
   x = mulll(a,a);
   return remll_pre(hiremainder, x, p, pi);
@@ -1897,7 +1900,7 @@ Fl_sqr_pre(ulong a, ulong p, ulong pi)
 INLINE ulong
 Fl_mul_pre(ulong a, ulong b, ulong p, ulong pi)
 {
-  register ulong x;
+  ulong x;
   LOCAL_HIREMAINDER;
   x = mulll(a,b);
   return remll_pre(hiremainder, x, p, pi);
@@ -2037,7 +2040,7 @@ Fl_center(ulong u, ulong p, ulong ps2) { return (long) (u > ps2)? u - p: u; }
 INLINE ulong
 Fl_mul(ulong a, ulong b, ulong p)
 {
-  register ulong x;
+  ulong x;
   LOCAL_HIREMAINDER;
   x = mulll(a,b);
   if (!hiremainder) return x % p;
@@ -2046,7 +2049,7 @@ Fl_mul(ulong a, ulong b, ulong p)
 INLINE ulong
 Fl_sqr(ulong a, ulong p)
 {
-  register ulong x;
+  ulong x;
   LOCAL_HIREMAINDER;
   x = mulll(a,a);
   if (!hiremainder) return x % p;
